@@ -218,6 +218,7 @@ class Loader(object):
             actions_info[action] = {}
             actions_info[action]["name"] = service_model["actions"][action]["name"]
             actions_info[action]["document"] = service_model["actions"][action]["document"]
+            actions_info[action]["status"] = service_model["actions"][action].get("status", "online")
         return actions_info
 
     def get_service_all_version_actions(self, service):
@@ -256,6 +257,9 @@ class Loader(object):
     def get_action_description(self, service, version, action):
         return self.get_actions_info(service, version)[action]['document']
 
+    def get_action_online_status(self, service, version, action):
+        return self.get_actions_info(service, version)[action].get('status', 'online')
+
     def get_action_usage(self, service, action):
         return "tccli %s %s [--param...]" % (service, action)
 
