@@ -314,6 +314,9 @@ SERVICE_VERSIONS = {
     "gme": [
         "2018-07-11"
     ],
+    "goosefs": [
+        "2022-05-19"
+    ],
     "gpm": [
         "2020-08-20"
     ],
